@@ -390,10 +390,12 @@ do_pairwise_comp <- function (what, anova_obj, manyglm_object, verbose = FALSE,
     if (inherits(what, 'formula')) {
         if(attr(terms(what) , "response" ) != 0) stop('Formula for pairwise.comp must be onesided without a response. ie: "~ factor1:factor2"')
         # get a new matrix from this dataframe
-        mdf <- model.frame(what)
+        mdf <- try(model.frame(what),silent=TRUE)
+        if(inherits(mdf, "try-error")) #if this didn't work, try looking in object environment
+          mdf <- model.frame(what, data=manyglm_object$data)
         # add the column names, to the levels
         mdf <- lapply(colnames(mdf), function(x) paste(x, mdf[[x]], sep=':'))
-        # collapse all interactiions into one factor level
+        # collapse all interactions into one factor level
         what <- as.factor(Reduce(paste, mdf))
     }
     if (!is.factor(what)) what <- as.factor(what)
@@ -450,8 +452,12 @@ do_pairwise_comp <- function (what, anova_obj, manyglm_object, verbose = FALSE,
         }
     }
 
+    # correct for NaN values:
+    observed_stats[is.na(observed_stats)] <- 0
+    resampled_stats[is.na(resampled_stats)] <- 1
+    
     # now we can start the step down procedure
-    # sort observed in decreasing order saving the indicies
+    # sort observed in decreasing order saving the indices
     # these indicies are our r_i (pg66 resamplng based multiple testing)
     # decreasing because we are using the test statistics and not the 
     observed_stats <- sort(observed_stats, index.return = T, decreasing = T)
@@ -492,3 +498,4 @@ do_pairwise_comp <- function (what, anova_obj, manyglm_object, verbose = FALSE,
     rownames(pmat) <- comparison
     pmat
 }
+
